intelmq.bots.outputs.postgresql namespace — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.outputs.postgresql namespace

## Submodules

## intelmq.bots.outputs.postgresql.output module

Compatibility shim

`intelmq.bots.outputs.postgresql.output.` `BOT`

  alias of `intelmq.bots.outputs.postgresql.output.PostgreSQLOutputBot`

class `intelmq.bots.outputs.postgresql.output.` `PostgreSQLOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.bots.outputs.sql.output.SQLOutputBot`

  `init`()